summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorrstular <rok@stular.eu>2020-05-17 14:07:41 +0200
committerrstular <rok@stular.eu>2020-05-17 14:07:41 +0200
commit5c7cf884235fd1a65e83091793e525451e317d8c (patch)
treef7ef152c493159de133b791da231f10dbd029164
parentFixed install script (diff)
downloadbeziapp-5c7cf884235fd1a65e83091793e525451e317d8c.tar
beziapp-5c7cf884235fd1a65e83091793e525451e317d8c.tar.gz
beziapp-5c7cf884235fd1a65e83091793e525451e317d8c.tar.bz2
beziapp-5c7cf884235fd1a65e83091793e525451e317d8c.tar.lz
beziapp-5c7cf884235fd1a65e83091793e525451e317d8c.tar.xz
beziapp-5c7cf884235fd1a65e83091793e525451e317d8c.tar.zst
beziapp-5c7cf884235fd1a65e83091793e525451e317d8c.zip
-rw-r--r--assets/js/gsec.js2
-rw-r--r--dist/js/gsec.js2
-rw-r--r--dist/pages/about.html2
-rw-r--r--dist/sw.js4
4 files changed, 5 insertions, 5 deletions
diff --git a/assets/js/gsec.js b/assets/js/gsec.js
index 6bd8f52..6c3de0f 100644
--- a/assets/js/gsec.js
+++ b/assets/js/gsec.js
@@ -290,7 +290,7 @@ class gsec {
fetchTeachers() { // razrednika ne vrne kot razrednika, če le-ta uči še en predmet. razlog: razrednik je napisan dvakrat, drugič se prepiše. Ne da se mi popravljat.
- const SUBJECT_REGEX = /^(.+?) \(/;
+ const SUBJECT_REGEX = /^(.+?(?= \()|.+(?! \())/; // For some reason, JS doesn't support conditional regex
const ABKURZUNG_REGEX = /\((.+?)\)/;
const DAY_REGEX = /^(.+?), /;
const PERIOD_REGEX = /, (\d+?)\. ura/;
diff --git a/dist/js/gsec.js b/dist/js/gsec.js
index 6bd8f52..6c3de0f 100644
--- a/dist/js/gsec.js
+++ b/dist/js/gsec.js
@@ -290,7 +290,7 @@ class gsec {
fetchTeachers() { // razrednika ne vrne kot razrednika, če le-ta uči še en predmet. razlog: razrednik je napisan dvakrat, drugič se prepiše. Ne da se mi popravljat.
- const SUBJECT_REGEX = /^(.+?) \(/;
+ const SUBJECT_REGEX = /^(.+?(?= \()|.+(?! \())/; // For some reason, JS doesn't support conditional regex
const ABKURZUNG_REGEX = /\((.+?)\)/;
const DAY_REGEX = /^(.+?), /;
const PERIOD_REGEX = /, (\d+?)\. ura/;
diff --git a/dist/pages/about.html b/dist/pages/about.html
index 16b0540..be31e44 100644
--- a/dist/pages/about.html
+++ b/dist/pages/about.html
@@ -142,7 +142,7 @@
<div class="row">
<p>
<small>
- ^HEAD c2d13f23711f90b86cff6ca06552b69dd2228932
+ ^HEAD 96dd81ddf1188377bf1402e866c4b263dbd55d1c
</p>
</div>
</div>
diff --git a/dist/sw.js b/dist/sw.js
index 57d1646..c2a150b 100644
--- a/dist/sw.js
+++ b/dist/sw.js
@@ -3,8 +3,8 @@
// Change version to cause cache refresh
-const static_cache_name = "site-static-1.0.13-beta-c2d13f2";
-// latest commit is c2d13f23711f90b86cff6ca06552b69dd2228932
+const static_cache_name = "site-static-1.0.13-beta-96dd81d";
+// latest commit is 96dd81ddf1188377bf1402e866c4b263dbd55d1c
// Got them with find . -not -path '*/\.*' | sed "s/.*/\"&\",/" | grep -v sw.js
// sw.js NE SME BITI CACHAN, ker vsebuje verzijo!